pub struct UnbatchableProofPart<B = BigNumDig>where
B: Big,{
pub l_hash_inc: u32,
pub r: <B as Big>::Num,
}Expand description
The part of PoKE* (Proof of Knowledge of Exponent) proofs that can’t be batched. This is very small (serialized typically <20 bytes, most likely just 17 bytes).
Fields
l_hash_inc: u32The number to increase a hash by to land on the next prime. Helps to more quickly generate/verify the prime number $l$.
r: <B as Big>::NumA part of the proof, the residue of the element that’s proven, i.e. $r$ in $element = q*l + r$